@@ -1,4 +1,4 @@
-from .request import RequestMiddleware  # noqa F401
+from .request import RequestMiddleware, request_middleware_router  # noqa F401
 
 # noinspection PyUnresolvedReferences
 from ..celery.middlewares import CeleryMiddleware  # noqa F401
